@@ -1,6 +1,6 @@
 // vector<bool> specialization -*- C++ -*-
 
-// Copyright (C) 2001-2025 Free Software Foundation, Inc.
+// Copyright (C) 2001-2024 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -787,7 +787,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
 
       _GLIBCXX20_CONSTEXPR
       explicit
-      vector(const allocator_type& __a) _GLIBCXX_NOEXCEPT
+      vector(const allocator_type& __a)
       : _Base(__a) { }
 
 #if __cplusplus >= 201103L
@@ -1132,9 +1132,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
       operator[](size_type __n)
       {
 	__glibcxx_requires_subscript(__n);
-	return _Bit_reference (this->_M_impl._M_start._M_p
-			       + __n / int(_S_word_bit),
-			       1UL << __n % int(_S_word_bit));
+	return begin()[__n];
       }
 
       _GLIBCXX_NODISCARD _GLIBCXX20_CONSTEXPR
@@ -1142,9 +1140,7 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
       operator[](size_type __n) const
       {
 	__glibcxx_requires_subscript(__n);
-	return _Bit_reference (this->_M_impl._M_start._M_p
-			       + __n / int(_S_word_bit),
-			       1UL << __n % int(_S_word_bit));
+	return begin()[__n];
       }
 
     protected:
@@ -1341,9 +1337,9 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
 		      std::copy_backward(__pos._M_const_cast(), end(),
 					 this->_M_impl._M_finish
 					   + difference_type(__n));
-		      ranges::copy(__rg, __pos._M_const_cast());
+		      auto __i = ranges::copy(__rg, __pos._M_const_cast()).out;
 		      this->_M_impl._M_finish += difference_type(__n);
-		      return __pos._M_const_cast();
+		      return __i;
 		    }
 		  else
 		    {
@@ -1355,9 +1351,9 @@ _GLIBCXX_BEGIN_NAMESPACE_CONTAINER
 		      iterator __i = _M_copy_aligned(__begin,
 						     __pos._M_const_cast(),
 						     __start);
-		      iterator __j = ranges::copy(__rg, __i).out;
+		      __i = ranges::copy(__rg, __i).out;
 		      iterator __finish = std::copy(__pos._M_const_cast(),
-						    __end, __j);
+						    __end, __i);
 		      this->_M_deallocate();
 		      this->_M_impl._M_end_of_storage = __q + _S_nword(__len);
 		      this->_M_impl._M_start = __start;
