@@ -1,6 +1,6 @@
 // Predefined symbols and macros -*- C++ -*-
 
-// Copyright (C) 1997-2025 Free Software Foundation, Inc.
+// Copyright (C) 1997-2024 Free Software Foundation, Inc.
 //
 // This file is part of the GNU ISO C++ Library.  This library is free
 // software; you can redistribute it and/or modify it under the
@@ -46,7 +46,7 @@
 
 // The datestamp of the C++ library in compressed ISO date format.
 #undef __GLIBCXX__ /* The testsuite defines it to 99999999 to block PCH.  */
-#define __GLIBCXX__ 20250223
+#define __GLIBCXX__ 20241103
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -169,7 +169,7 @@
 #endif
 
 // Macro to warn about unused results.
-#if __cplusplus >= 201103L
+#if __cplusplus >= 201703L
 # define _GLIBCXX_NODISCARD [[__nodiscard__]]
 #else
 # define _GLIBCXX_NODISCARD
@@ -610,7 +610,7 @@ namespace std
 {
 #pragma GCC visibility push(default)
   // Don't use <cassert> because this should be unaffected by NDEBUG.
-  extern "C++" _GLIBCXX_NORETURN __attribute__((__cold__))
+  extern "C++" _GLIBCXX_NORETURN
   void
   __glibcxx_assert_fail /* Called when a precondition violation is detected. */
     (const char* __file, int __line, const char* __function,
@@ -626,17 +626,14 @@ namespace std
 #endif
 
 #if defined(_GLIBCXX_ASSERTIONS)
-// When _GLIBCXX_ASSERTIONS is defined we enable runtime assertion checks.
-// These checks will also be done during constant evaluation.
+// Enable runtime assertion checks, and also check in constant expressions.
 # define __glibcxx_assert(cond)						\
   do {									\
     if (__builtin_expect(!bool(cond), false))				\
       _GLIBCXX_ASSERT_FAIL(cond);					\
   } while (false)
 #elif _GLIBCXX_HAVE_IS_CONSTANT_EVALUATED
-// _GLIBCXX_ASSERTIONS is not defined, so assertions checks are only enabled
-// during constant evaluation. This ensures we diagnose undefined behaviour
-// in constant expressions.
+// Only check assertions during constant evaluation.
 namespace std
 {
   __attribute__((__always_inline__,__visibility__("default")))
@@ -646,12 +643,12 @@ namespace std
 }
 # define __glibcxx_assert(cond)						\
   do {									\
-    if (std::__is_constant_evaluated() && !bool(cond))			\
-      std::__glibcxx_assert_fail();					\
+    if (std::__is_constant_evaluated())					\
+      if (__builtin_expect(!bool(cond), false))				\
+	std::__glibcxx_assert_fail();					\
   } while (false)
 #else
-// _GLIBCXX_ASSERTIONS is not defined and __is_constant_evaluated() doesn't
-// work so don't check any assertions.
+// Don't check any assertions.
 # define __glibcxx_assert(cond)
 #endif
 
@@ -885,7 +882,7 @@ namespace __gnu_cxx
 #ifdef __has_builtin
 # ifdef __is_identifier
 // Intel and older Clang require !__is_identifier for some built-ins:
-#  define _GLIBCXX_HAS_BUILTIN(B) (__has_builtin(B) || ! __is_identifier(B))
+#  define _GLIBCXX_HAS_BUILTIN(B) __has_builtin(B) || ! __is_identifier(B)
 # else
 #  define _GLIBCXX_HAS_BUILTIN(B) __has_builtin(B)
 # endif
